@@ -2,5 +2,5 @@ from django.apps import AppConfig
 
 
 class OneTimeLinkConfig(AppConfig):
-    name = 'OneTimeLink'
-    verbose_name = 'OneTimeLink'
+    name = 'onetimelink'
+    verbose_name = 'onetimelink'
